@@ -21,12 +21,16 @@ from rest_framework.request import Request
 from rest_framework.response import Response
 from TDhelper.generic.classDocCfg import doc
 from TDhelper.generic.dictHelper import createDictbyStr, findInDict
-from TDhelper.network.http.REST_HTTP import GET, POST, PUT, DELETE, serializePostData
-from TDhelper.generic.requier import R, InstanceCall
+from TDhelper.network.http.REST_HTTP import GET, POST, PUT, DELETE, serializePostData,ContentType
+from TDhelper.generic.requier import R as require, InstanceCall
 from TDhelper.generic.randGetValue import getValue
+from TDhelper.network.rpc.Client.rpc import client
 
 # code start
 
+# 反射获取类
+def reflectClass(cls):
+    return require(cls).getType()
 
 class Event:
     """
@@ -42,7 +46,44 @@ class Event:
         self._httpHeaders = httpHeaders
         self._httpHeaders["api-token"] = secret if secret else ""
 
-    def Register(self, serviceClass=None):
+    def AutoRegister(self,conf_path:str=None,svr_cls:list=[])->None:
+        '''auto regist event class
+
+        Parameters:
+            
+            conf_path: <class:str> event configure file path, required(false)
+
+            svr_cls: <class:list>
+
+        Return: None
+        '''
+        if conf_path:
+            try:
+                conf= None
+                with open(conf_path,mode='r') as f:
+                    conf= json.load(f)
+                    f.close()
+                if conf:
+                    for k,v in conf.items():
+                        self.__registerByConf__(k,v)
+            except Exception as e:
+                raise e
+        if svr_cls:
+            try:
+                for item in svr_cls:
+                    self.Register(reflectClass(item))
+            except Exception as e:
+                raise e
+
+    def Register(self, serviceClass)->None:
+        '''event regist by class.
+
+        Parameters:
+
+            serviceClass: <class: class>, python class, class must configure event in docString.
+
+        Return: None
+        '''
         for k, v in serviceClass.__dict__.items():
             if isinstance(v, FunctionType):
                 if not k.startswith("__"):
@@ -57,7 +98,7 @@ class Event:
         if config:
             config = re.sub(r"[\r|\n]", r"", config, count=0, flags=0).strip()
             try:
-                config = json.loads(config, encoding="utf-8")
+                config = json.loads(config)#, encoding="utf-8")
                 try:
                     if config:
                         if "key" in config["handle"]:
@@ -136,6 +177,36 @@ class Event:
                 config = None
                 logging.error("config is none.")
 
+    def __registerByConf__(self,k:str,conf:any):
+                        conf["handle"].update({"plateformKey":self._platformKey})
+                        k= self._platformKey + "." + k.upper()
+                        if 'key' in conf:
+                            k= conf["key"]
+                            k= self._platformKey+"."+k.upper()
+                        state, body = POST(
+                            self._event_uri + "handle/",
+                            post_data=conf["handle"],
+                            http_headers=self._httpHeaders,
+                            time_out=15,
+                        )
+                        if state == 200:
+                            ret = body
+                            if isinstance(body, bytes):
+                                ret = json.loads(str(body, encoding="utf-8"))
+                            if ret["state"] == 200:
+                                logging.info("handle(%s) register SUCCESS" % k)
+                                handleId = ret["msg"]["id"]
+                                if "trigger" in conf:
+                                    self._triggerRegister(
+                                        k, handleId, conf["trigger"]
+                                    )
+                            else:
+                                logging.error(
+                                    "register handle %s is error. %s" % (k, ret["msg"])
+                                )
+                        else:
+                            logging.error("access register service failed.%s" % body)
+    
     def _triggerRegister(self, handle, handleId, config):
         # todo register trigger
         # , name: str, section: str, sync: bool = False, systemEvent: bool = False, handle: int = None
@@ -168,7 +239,7 @@ class Event:
 
 
 class Manager:
-    def __init__(self, service_uri, platformKey: str, RPCInstance, event_secret=None):
+    def __init__(self, service_uri, platformKey: str, RPCInstance:client, event_secret=None):
         """
         event manager class.
         - Params:
@@ -185,11 +256,11 @@ class Manager:
         self._RPCInstance = RPCInstance
         self._RPC = {}
 
-    def registerRPC(self, service_name):
-        """
-        register RPC service into event class.
-        """
-        self._RPC[service_name] = self._RPCInstance.handle(service_name)
+    #def registerRPC(self, service_name):
+    #    """
+    #    register RPC service into event class.
+    #    """
+    #    self._RPC[service_name] = self._RPCInstance.handle(service_name)
 
     def _getRemoteEventRelation(self):
         if not self._event_cache:
@@ -634,26 +705,36 @@ class Manager:
             if len(m_handle) == 2:
                 m_service = m_handle[0]
                 m_handle = m_handle[1]
-                if m_service not in self._RPC:
-                    self._RPC[m_service] = self._RPCInstance.handle(m_service)
-                if m_service in self._RPC:
+                if self._RPCInstance.__dict__.__contains__(m_service):
                     params_ret = self._generic_params(m_params, False, *args, **kwargs)
-                    rpc_result = self._RPC[m_service].call(
-                        item["callHandle"], **params_ret
-                    )
-                    if rpc_result["state"] == 200:
-                        return True, rpc_result
+                    if hasattr(self._RPCInstance.__dict__[m_service],m_handle):
+                        try:
+                            rpc_result= getattr(self._RPCInstance.__dict__[m_service],m_handle)(**kwargs)#(**params_ret)#(**kwargs) unitTest.
+                            if rpc_result["state"] == 200:
+                                return True, rpc_result
+                            else:
+                                return False, rpc_result
+                        except Exception as e:
+                            logging.error("TDhelper.Event.webEvent.Events._rpc_call(%s.%s), %s"%(m_service,m_handle,str(e.args)))
+                            return False, "TDhelper.Event.webEvent.Events._rpc_call(%s.%s), %s"%(m_service,m_handle,str(e.args))
                     else:
-                        return False, rpc_result
+                        logging.error("TDhelper.Event.webEvent.Events._rpc_call method, can not found '%s' method in '%s'"%(m_handle,m_service))
+                        return False, "TDhelper.Event.webEvent.Events._rpc_call method, can not found '%s' method in '%s'"%(m_handle,m_service)
+                    #rpc_result = self._RPC[m_service].call(
+                    #    item["callHandle"], **params_ret
+                    #)
                 else:
-                    return False, "can not found '%s' service." % m_service
+                    logging.error("can not found '%s' service." % m_service)
+                    return False, "TDhelper.Event.webEvent.Events._rpc_call method, can not found '%s' service." % m_service
             else:
+                logging.error("TDhelper.Event.webEvent.Events._rpc_call method, trigger handle formatter error. formatter(serviceName.method)")
                 return (
                     False,
-                    "handle formatter is error. formatter(serviceName.methodName)",
+                    "TDhelper.Event.webEvent.Events._rpc_call method, trigger handle formatter is error. formatter(serviceName.methodName)",
                 )
         else:
-            return False, "handle is none."
+            logging.error("TDhelper.Event.webEvent.Events._rpc_call method, handle is none.")
+            return False, "TDhelper.Event.webEvent.Events._rpc_call method, handle is none."
 
     def _api_call(self, item, *args, **kwargs):
         """
