@@ -1,10 +1,10 @@
 
 class Scheduler():
-    def __init__(self,name,plug,taskType="interval",startTime=None,sleep=0):
+    def __init__(self,name,plugin,taskType="interval",startTime=None,sleep=0):
         """Init task
             params:
                 name: str
-                plug:call task module
+                plugin:call task module
                 taskType:task type
                     realtime:run at now
                     interval:loop run and sleep N millisecond,default value
@@ -14,7 +14,7 @@ class Scheduler():
         """
         self.__config={
         'name':name,
-        'plug':plug,
+        'plugin':plugin,
         'type':taskType,#realtime,interval,timing
         'starttime':startTime,
         'sleep':sleep,#millisecond;
