@@ -2,16 +2,17 @@ from TDhelper.Scheduler.base import *
 
 import abc
 import six
+import asyncio
 
 @six.add_metaclass(abc.ABCMeta)
 class InterfaceScheduler(Scheduler):
     @abc.abstractmethod
-    def __init__(self,name,plug,taskType="interval",startTime=None,sleep=0):
+    def __init__(self,name,plugin,taskType="interval",startTime=None,sleep=0):
         """Init
 
             Params:
                 name:taskName
-                plug:call task module
+                plugin:call task module
                 taskType:task type
                     realtime:run at now
                     interval:loop run and sleep N millisecond,default value
@@ -19,9 +20,9 @@ class InterfaceScheduler(Scheduler):
                 startTime:first run time
                 sleep:sleep millisecond
         """
-        super(InterfaceScheduler,self).__init__(name,plug,taskType,startTime,sleep)
+        super(InterfaceScheduler,self).__init__(name,plugin,taskType,startTime,sleep)
 
     @abc.abstractmethod
-    def run(self,*args,**kw):
+    async def run(self,*args,**kw):
         """Run process
         """
\ No newline at end of file
