@@ -108,7 +108,7 @@ class Analysis(Event):
                 # 控制访问频率延时.
                 time.sleep(self.__access_delays)
 
-    def search(self, params:[]= []):
+    def search(self, params:list= []):
         if params:       
             for key,config in self.__config.items():
                 self.__configKey= key
