@@ -5,38 +5,38 @@ import six
 class cacheInterface:
     __cache__={}
     __cursor__=None
-    @abc.abstractclassmethod
+    @abc.abstractmethod
     def __init__(self):
         pass
     
-    @abc.abstractclassmethod
+    @abc.abstractmethod
     def set(self,*args,**kwargs):
         pass
         
-    @abc.abstractclassmethod
+    @abc.abstractmethod
     def get(self,flag='single',*args,**kwargs):
         pass
     
-    @abc.abstractclassmethod
+    @abc.abstractmethod
     def exist(self,*args,**kwargs):
         pass
     
-    @abc.abstractclassmethod
+    @abc.abstractmethod
     def collect(self,*args,**kwargs):
         pass
     
-    @abc.abstractclassmethod
+    @abc.abstractmethod
     def addCollect(self,k,v):
         pass
     
-    @abc.abstractclassmethod        
+    @abc.abstractmethod        
     def delCollect(self,k):
         pass
     
-    @abc.abstractclassmethod   
+    @abc.abstractmethod   
     def remove(self,*args,**kwargs):
         pass
     
-    @abc.abstractclassmethod   
+    @abc.abstractmethod   
     def update(self,*args,**kwargs):
         pass
\ No newline at end of file
