@@ -16,7 +16,7 @@ class webCacheFactory:
             raise Exception("cls must value: memory | mongo | redis.")
     
     def set(self,*args,**kwargs):
-        self.__handle__.set(*args,**kwargs)
+        return self.__handle__.set(*args,**kwargs)
         
     def get(self,flag='single',*args,**kwargs):
         return self.__handle__.get(flag,*args,**kwargs)
@@ -25,16 +25,17 @@ class webCacheFactory:
         return self.__handle__.exist(*args,**kwargs)
     
     def collect(self,k):
-        return self.__handle__.collect(k)
+        self.__handle__.collect(k)
+        return self
     
     def addCollect(self,k,v):
-        self.__handle__.addCollect(k,v)
+        return self.__handle__.addCollect(k,v)
          
     def delCollect(self,k):
-        self.__handle__.delCollect(k)
+        return self.__handle__.delCollect(k)
     
     def remove(self,*args,**kwargs):
-        self.__handle__.remove(*args,**kwargs)
+        return self.__handle__.remove(*args,**kwargs)
     
     def update(self,*args,**kwargs):
-        self.__handle__.update(*args,**kwargs)
\ No newline at end of file
+        return self.__handle__.update(*args,**kwargs)
\ No newline at end of file
