@@ -24,7 +24,7 @@ class mongodbclient:
             if "url" in kwargs and 'db' in kwargs:
                 if kwargs['url']:
                     try:
-                        self.client=pymongo.MongoClient(kwargs['url'])
+                        self.client=pymongo.MongoClient(kwargs['url'],connect=False)
                         if self.client:
                             if kwargs['db']:
                                 self.db=self.client[kwargs['db']]
