@@ -11,6 +11,10 @@ class _AttributeOverride:
         return instance.__dict__[self._name]
 
     def __set__(self, instance, value):
+        if self._type== str:
+            value= value.replace("'","")
+            if len(value)<=0:
+                value= None
         instance.__dict__[self._name] = transformation(value, self._type)
 
     def __delete__(self, instance):
