@@ -1,11 +1,10 @@
-from distutils.log import error
-from meta import iniMeta
+from TDhelper.document.ini.meta import iniMeta
 import os
 
 
 class model(metaclass=iniMeta):
     def __init__(self, source):
-        assert isinstance(source, str), error("source is not str type.")
+        assert isinstance(source, str), "source is not str type."
         if os.path.exists(source):
             self.Meta.source = source if isinstance(source, str) else [source]
             self.__instance__()
