@@ -6,6 +6,6 @@ class t(model):
     b= FieldType(int,"SERVICE.name")
 
 if __name__ == "__main__":
-    a= t(r"C:\Home\dev\Python\pypi\src\TDhelper\document\ini\1.ini")
+    a= t(r"/home/ubuntu/dev/pyLib/TDhelper/document/ini/1.ini")
     print(a.a)
     print(a.b)
\ No newline at end of file
