@@ -3,6 +3,8 @@ import os
 import sys
 import re
 import json
+
+from TDhelper.generic.dictHelper import findInDict
 def doc(source_str, key):
     result= ''
     isRead= False
@@ -36,8 +38,7 @@ def doc(source_str, key):
                 if m_key:
                     result= json.loads(result)
                     for k in m_key:
-                        if k in result:
-                            result= result[k]
+                        result= findInDict(k,result)
                     if isinstance(result, dict):
                         result= json.dumps(result)
                 f.close()
