@@ -1,5 +1,5 @@
 import hashlib
-from generic.transformationType import transformation
+from TDhelper.generic.transformationType import transformation
 
 def MD5(s:"str|list|dict",encoding="utf-8"):
     m= hashlib.md5()
