@@ -102,7 +102,7 @@ def GET(
         return e.code, e.reason
     except URLError as e:
         if isinstance(e.reason, socket.timeout):
-            return 408, None
+            return 408, "Time Out"
         else:
             return e.reason, None
 
@@ -159,7 +159,7 @@ def POST(
         return e.code, e.reason
     except URLError as e:
         if isinstance(e.reason, socket.timeout):
-            return 408, None
+            return 408, "Time Out"
         else:
             return e.reason.errno, e.reason.strerror
 
@@ -197,7 +197,7 @@ def DELETE(uri, post_data={}, http_headers=None, content_type=ContentType.URLENC
         return e.code, e.reason
     except URLError as e:
         if isinstance(e.reason, socket.timeout):
-            return 408, None
+            return 408, "Time Out"
         else:
             return e.reason, None
 
@@ -222,6 +222,6 @@ def PUT(uri, post_data: bytes, http_headers=None, content_type= ContentType.URLE
         return e.code, e.reason
     except URLError as e:
         if isinstance(e.reason, socket.timeout):
-            return 408, None
+            return 408, "Time out"
         else:
             return e.reason, None
