@@ -6,7 +6,9 @@ from TDhelper.generic.requier import R as require
 from TDhelper.generic.classDocCfg import doc
 from TDhelper.network.rpc.Core.Meta import Meta
 from TDhelper.network.rpc.Core.struct import *
+from TDhelper.network.rpc.Core.token import token_manage
 from TDhelper.network.http.REST_HTTP import GET, POST, PUT, DELETE, ContentType
+
 # 反射获取类
 def reflectClass(cls):
     return require(cls).getType()
@@ -16,8 +18,23 @@ class SRC(metaclass=Meta):
         service register center interface.
     Parameters:
         uris - <class:list>, rpc server apis.
-        token - <class:str>, rpc apis access token.
         server_cnf - <class:dict>, service conf.
+        rpc_conf_header - <class:dict>, rpc configure general header struct. example :{
+                    "name": "权限服务",
+                    "description": "权限服务",
+                    "key": "RPC_TEST",
+                    "secret": "203920398409238408204324",
+                    "protocol": "http://",
+                    "hosts": [
+                        {
+                            "serverId": 1,
+                            "host": "192.168.0.1",
+                            "port": 8080,
+                            "sniffer": "api/sniffer",
+                            "proto": "http://"
+                        }
+                    ]
+                } 
         logger - <class:logging>, log handle.
         **kwargs:
             token_key - <class:str>, access token key. it will auto assembly http header. default 'api-token'.
@@ -26,12 +43,25 @@ class SRC(metaclass=Meta):
     Raises:
         None
     """
-    def __init__(self, uris: list, token: str, server_cnf: dict = None, logger: "logging" = None,**kwargs):
-        self.__RPC_CNF__ = RPC_SERVICE_CONF(uris, token)
+    def __init__(self, uris: list, server_cnf: dict = None, rpc_conf_header:dict={}, logger: "logging" = None,**kwargs):
+        self.__RPC_CNF__ = RPC_SERVICE_CONF(uris)
+        self.__token_manage__= token_manage(
+            self.__RPC_CNF__.getUri(),
+            rpc_conf_header.get("key"),
+            rpc_conf_header.get('secret'),
+            path="api/regist_monent_token",
+            post_data={
+                "svr_key": rpc_conf_header.get("key")
+            }
+        )
         self.__logger_hander__ = logger if logger else self.__logger_hander__
         self.__rpc_server_cnf__ = server_cnf if server_cnf else self.__rpc_server_cnf__
         apiToken="api-token" if "token_key" not in kwargs else kwargs["token_key"]
-        self.__headers__[apiToken] = self.__RPC_CNF__.token
+        #self.__headers__[apiToken] = self.__token_manage__.Token#self.__RPC_CNF__.token
+        self.__rpc_conf_header__= rpc_conf_header
+        self.__headers__.update({apiToken:self.__token_manage__.Token})
+        self.__headers__.update({"access-source":"service_regist"})
+        self.__headers__.update({"svr-key":rpc_conf_header.get("key")})
 
     def __set_coding__(self, encoding='utf-8'):
         self.__ENCODING__ = encoding
@@ -39,12 +69,12 @@ class SRC(metaclass=Meta):
     def __setting__(self, cnf):
         self.__rpc_server_cnf__ = cnf
 
-    def AutoRegister(self,conf,cxt:list):
+    def AutoRegister(self,cxt:list,conf_header:dict= None):
         """AutoRegister
             Auto register service by method annotate.
         Parameters:
-            conf - <class:dict>, service and host conf.
             cxt - <class:list>, want to auto register cls.
+            conf_header - <class:dict>, override rpc configure general header struct.
         Returns:
             None
         Raises:
@@ -85,6 +115,9 @@ class SRC(metaclass=Meta):
                 fun1::test.json
                 [rpcend]
         """
+        conf= conf_header if conf_header else copy(self.__rpc_conf_header__)
+        if not conf:
+            raise Exception("configure header is none. see more in config/regist_conf/readme.md")
         if "methods" not in conf:
             conf['methods']={}
         for cxt_item in cxt:
@@ -93,7 +126,7 @@ class SRC(metaclass=Meta):
                 m_cxt= reflectClass(cxt_item)
             for k, v in m_cxt.__dict__.items():
                 if isinstance(v, FunctionType):
-                    func_name = v.__name__.upper()
+                    func_name = "".join([m_cxt.__name__,'_',v.__name__]).upper()
                     if v.__doc__:
                         methods = doc(v.__doc__, "rpc")
                         if methods:
@@ -107,24 +140,46 @@ class SRC(metaclass=Meta):
         self.__register_by_cnf__(conf)
         return self
     
-    def Register(self, cxt:"dict|str", filepath:bool=False):
+    def Register(self, cxt:"dict|str", filepath:bool=False, conf_header:dict=None):
         """Register
             register service by conf.
         Parameters:
             cxt - <class:dict|str>, conf json or conf file path.
             filepath - <class:bool>, control conf mode. default False use dict to register.
+            conf_header - <class:dict>, override rpc configure general header struct.
         Returns:
             None
         Raises:
             None
         """
+        conf= conf_header if conf_header else copy(self.__rpc_conf_header__)
+        if not conf:
+            raise Exception("configure header is none. see more in config/regist_conf/readme.md")
+        
         if filepath:
             if os.path.exists(cxt):
-                self.__register_by_file__(cxt)
+                m_conf= self.__register_by_file__(cxt)
+                if conf:
+                    m_conf['name']=conf['name']
+                    m_conf['description']=conf['description']
+                    m_conf['key']=conf['key']
+                    m_conf['secret']=conf['secret']
+                    m_conf['protocol']=conf['protocol']
+                    m_conf['hosts']=conf['hosts']
+                if "methods" in m_conf:
+                    conf.update(m_conf)
+                else:
+                    conf.update({"methods":m_conf})
+                self.__register_by_cnf__(conf)
             else:
                 raise Exception("can not found path '%s'" % cxt)
         else:
-            self.__register_by_cnf__(cxt)
+            if "methods" in cxt:
+                if "methods" in cxt:
+                    conf.update(cxt)
+                else:
+                    conf.update({"methods":cxt})
+            self.__register_by_cnf__(conf)
         return self
 
     def __register_by_file__(self, filepath):
@@ -133,7 +188,7 @@ class SRC(metaclass=Meta):
         with open(filepath, mode='r', encoding=self.__ENCODING__) as f:
             m_json_source = f.read()
             f.close()
-        self.__register_by_cnf__(json.loads(m_json_source))
+        return json.loads(m_json_source)
 
     def __register_by_cnf__(self, cnf: "dict|str"):
         if isinstance(cnf, str):
@@ -148,6 +203,7 @@ class SRC(metaclass=Meta):
         if state:
             res = json.loads(res)
             if res["state"] == 200:
+                self.__logger_hander__.info("service(%s) register success."%res['msg']['name'])
                 s_id = res["msg"]["id"]
                 self.__register_host__(s_id)
                 self.__register_method__(s_id)
