@@ -3,8 +3,8 @@ import logging
 import html
 from random import Random
 from TDhelper.network.rpc.Generic.Host import HostManager
-from network.http.REST_HTTP import GET, POST, PUT, DELETE, ContentType
-
+from TDhelper.network.http.REST_HTTP import GET, POST, PUT, DELETE, ContentType
+from TDhelper.network.rpc.Core.token import token_manage
 
 def get_key(key, cnf):
     return cnf[key] if key in cnf else None
@@ -179,9 +179,14 @@ class RPC_Method:
             except Exception as e:
                 raise e
         if 'collect' in cnf:
-            if get_key('collect', cnf):
-                name = "".join(
+            m_collect= get_key('collect',cnf)
+            if m_collect:
+                if not key.upper().startswith(m_collect.upper()+"_"):
+                    name = "".join(
                     [name, '.', get_key('collect', cnf).upper(), '_', key])
+                else:
+                    name = "".join(
+                    [name, '.', key])
             else:
                 name = "".join([name, '.', key])
         else:
@@ -207,8 +212,10 @@ class RPC_SERVICE:
     secret: str = None
     protocol: str = "http://"
     methods = {}
-
-    def __init__(self, name=None, description=None, key=None, secret=None, protocol=None, host_cnf=None, methods_cnf=None, token_key="api-token"):
+    __call_time_out=2
+    __method_exists__= lambda o,k: True if k in o.__dict__ else False
+    __token_manage:token_manage= None
+    def __init__(self, name=None, description=None, key=None, secret=None, protocol=None, host_cnf=None, methods_cnf=None, token_key="api-token",token_manage:token_manage=None,call_time_out=2):
         self.__TOKEN_KEY__ = token_key
         self.name = name
         self.description = description
@@ -217,6 +224,8 @@ class RPC_SERVICE:
         self.protocol = protocol
         self.host = HostManager()
         self.methods={}
+        self.__token_manage= token_manage
+        self.__call_time_out= call_time_out
         if host_cnf:
             for item in host_cnf:
                 self.host.register(
@@ -233,7 +242,9 @@ class RPC_SERVICE:
                     self.key.upper(), k.upper(), v)
             # self.methods = [RPC_Method.create_by_cnf(
             #    self.key.upper(), k.upper(), v) for k, v in methods_cnf.items()]
-
+    def __get_token__():
+        pass
+    
     def toCnf(self):
         return json.dumps({
             "name": self.name,
@@ -243,6 +254,12 @@ class RPC_SERVICE:
             "protocol": self.protocol
         })
 
+    def monitor(self,speed=None):
+        self.host.__start_state_monitor__(speed)
+        
+    def stop_monitor(self):
+        self.host.__stop_state_monitor__()
+    
     def __hit_method__(self, key):
         if key in self.methods:
             return self.methods[key]
@@ -252,7 +269,7 @@ class RPC_SERVICE:
     def __remote_call__(self, func_name, *args, **kwargs):
         logging.info("remote call %s.%s" % (self.key, func_name))
         method = self.__hit_method__(func_name)
-        m_uri = self.__genrate_method_uri__(func_name)
+        m_uri,serverId = self.__genrate_method_uri__(func_name)
         if not m_uri:
             return {"state": -1, "msg": "%s not found remote uri." % self.__name__+func_name}
         try:
@@ -281,16 +298,16 @@ class RPC_SERVICE:
             state, ret = GET(uri=uri,
                              post_data=kwargs,
                              http_headers=http_headers,
-                             time_out=15)
+                             time_out=self.__call_time_out)
         elif method_type.upper() == "POST":
             logging.info("access api:(%s), method(%s), postdata:%s." %
-                         (uri, method_type, kwargs["data"]))
+                         (uri, method_type, kwargs))
             state, ret = POST(
                 uri,
-                kwargs["data"],
+                kwargs["data"] if "data" in kwargs else None,
                 content_type=ContentType.JSON,
                 http_headers=http_headers,
-                time_out=15,
+                time_out=self.__call_time_out,
             )
         elif method_type.upper() == "PUT":
             logging.info("access api:(%s), method(%s),postdata:%s." %
@@ -307,12 +324,12 @@ class RPC_SERVICE:
                     post_data=kwargs["data"],
                     http_headers=method_type,
                     content_type=ContentType.JSON,
-                    time_out=15,
+                    time_out=self.__call_time_out,
                 )
             else:
                 state, ret = DELETE(uri=uri,
                                     http_headers=method_type,
-                                    time_out=15)
+                                    time_out=self.__call_time_out)
         else:
             return {"state": -1, "msg": "uri(%s),method type %s error." % (uri, method_type)}
         if state == 200:
@@ -331,11 +348,18 @@ class RPC_SERVICE:
         else:
             try:
                 if ret:
-                    ret = json.loads(str(ret, encoding="utf-8"))
-                    return {
-                        "state": ret["state"],
-                        "msg": ret["msg"]
-                    }
+                    if isinstance(ret,str):
+                        ret = ret
+                        return {
+                            "state": state,
+                            "msg": ret
+                        } 
+                    elif isinstance(ret,dict):
+                        ret = json.loads(str(ret, encoding="utf-8"))
+                        return {
+                            "state": ret["state"],
+                            "msg": ret["msg"]
+                        }
                 else:
                     return {"state": state, "msg": "%s" % uri}
             except Exception as e:
@@ -354,20 +378,33 @@ class RPC_SERVICE:
             if "headers" in kwargs:
                 if isinstance(kwargs["headers"], dict):
                     for o in kwargs["headers"]:
-                        m_headers[o.lower().replace("http_", "").replace(
-                            "_", "-").upper()] = kwargs["headers"][o]
+                        m_key=o.lower().replace('-',"_").replace("http_", "").replace("header_","").replace(
+                            "_", "-")
+                        m_headers[m_key] = kwargs["headers"][o]
                 else:
                     return {
                         "state": -1,
                         "msg": "http request headers must is dict type.",
                     }
-            m_headers[self.__TOKEN_KEY__] = self.secret
+            if "access-source" not in m_headers:
+                m_headers.update({"access-source":"rpc"})
+            if self.__TOKEN_KEY__ not in m_headers:
+                m_headers[self.__TOKEN_KEY__] = self.__token_manage.Token
+            for o in range(0,len(args)):
+                # args按顺序放入参数
+                try:
+                    kwargs.update({method.params[o].key:args[o]})
+                except Exception as e:
+                    raise(e)
             for item in method.params:
-                if item.key.upper().startswith("HTTP_HEADER_"):
-                    if item.key.replace("HTTP_HEADER_", "").replace("http_header_", "").replace("_", "-") not in m_headers:
+                if item.key.lower().startswith("http_header_"):
+                    if item.key.lower().replace("http_header_", "").replace("_", "-") not in m_headers:
+                        logging.info(item.key)
+                        logging.info(kwargs)
                         if item.key in kwargs:
-                            m_headers[item.key.replace("HTTP_HEADER_", "").replace(
+                            m_headers[item.key.lower().replace(
                                 "http_header_", "").replace("_", "-")] = kwargs[item.key]
+                            del kwargs[item.key]
                         else:
                             if item.default:
                                 m_headers[item.upper.replace("HTTP_HEADER_", "").replace(
@@ -375,7 +412,7 @@ class RPC_SERVICE:
                             else:
                                 raise Exception(
                                     "not found http header key(%s)" % item.key)
-                elif item.key.lower().startswith("http_data"):
+                elif item.key.lower().startswith("http_data_"):
                     if "data" not in kwargs:
                         kwargs["data"] = {}
                     if (item.key.replace("http_data_", "") not in kwargs["data"]):
@@ -383,6 +420,7 @@ class RPC_SERVICE:
                             kwargs["data"][item.key.replace(
                                 "http_data_",
                                 "")] = kwargs[item.key]
+                            del kwargs[item.key]
                         else:
                             if item.default:
                                 kwargs["data"][item.key.replace(
@@ -401,7 +439,7 @@ class RPC_SERVICE:
                                 item.default, str) else item.default
                         else:
                             raise Exception("not found params(%s)" % item.key)
-                    pass
+            del kwargs['headers']
             return m_headers, data, kwargs
         except Exception as e:
             logging.error(e)
@@ -409,20 +447,29 @@ class RPC_SERVICE:
 
     def __genrate_method_uri__(self, key):
         try:
-            host = self.host.__generateHost__(self.host.getHost()).strip('/')
+            host_conf=self.host.getHost()
+            host = self.host.__generateHost__(host_conf).strip('/')
             uri = self.__hit_method__(key).uri.strip('/')
-            return "".join([host, '/', uri, '/'])
+            return "".join([host, '/', uri, '/']),host_conf["serverId"]
         except Exception as e:
             logging.error(e)
             return None
 
     @classmethod
-    def create_by_cnf(self, cnf, token_key="api-token"):
+    def create_by_cnf(self, cnf,token_key="api-token",service_conf={},call_time_out=2):
         if isinstance(cnf, str):
             try:
                 cnf = json.loads(cnf)
             except Exception as e:
                 raise e
+        #print(get_key("key",cnf).upper())
+        token_m= token_manage(
+                token_uri= service_conf.get("uri",""),
+                svr_key=service_conf.get("service_key",""),
+                secret=service_conf.get("secret",""),
+                call_svr_key= service_conf.get("service_key",""),
+                post_data={}
+        )
         return RPC_SERVICE(
             name=get_key('name', cnf),
             description=get_key('description', cnf),
@@ -431,17 +478,19 @@ class RPC_SERVICE:
             protocol=get_key('protocol', cnf),
             host_cnf=get_key('hosts', cnf),
             methods_cnf=get_key('methods', cnf),
-            token_key=token_key
+            token_key=token_key,
+            #token_manage=token_manage,
+            token_manage= token_m,
+            call_time_out=call_time_out
         )
 
 
 class RPC_SERVICE_CONF:
     uris: list = []
-    token: str = None
 
-    def __init__(self, uris, token):
+    def __init__(self, uris):
         self.uris = uris
-        self.token = token
+        #self.token = token
         for offset in range(0, len(self.uris)):
             self.uris[offset] = self.uris[offset].strip("/")
 
