@@ -1,7 +1,9 @@
 from copy import deepcopy
 import random
+import time
+import logging
 from TDhelper.network.http.REST_HTTP import GET
-
+from threading import Thread
 
 class HostManager:
     def __init__(self) -> None:
@@ -9,8 +11,10 @@ class HostManager:
         self.__host_cnf__ = {}
         self.__host__ = []
         self.__host_len__ = 0
+        self.__monitor_speed__= 10
+        
         # self.__health_sniffer__ = ""
-
+        self.__monitor_state__= True
     def __backup_host__(self):
         self.__host_cnf_backup__ = deepcopy(self.__host_cnf__)
 
@@ -20,7 +24,7 @@ class HostManager:
         except Exception as e:
             raise e
 
-    def getHost(self):
+    def getHost(self,exclude:list=[]):
         """getHost
             get an access host cnf.
         Parameters:
@@ -36,6 +40,9 @@ class HostManager:
         while (True and retry > 0):
             v = 0 if self.__host_len__ == 1 else random.randint(
                 0, self.__host_len__-1)
+            if exclude:
+                if exclude.__contains__(v):
+                    continue
             result = self.__host_cnf__[self.__host__[v]]
             result["serverId"] = self.__host__[v]
             if result['status']:
@@ -43,6 +50,9 @@ class HostManager:
             retry -= 1
         return result
 
+    def del_host(self,k):
+        pass
+    
     def get_host_by_key(self, key):
         return self.__host_cnf__[key]
 
@@ -64,6 +74,7 @@ class HostManager:
         """
         serverId = str(serverId)
         proto = self.__checken_proto__(proto)
+        sniffer= sniffer if sniffer else "/api/sniffer"
         if serverId not in self.__host_cnf__:
             self.__host_cnf__[serverId] = {
                 "proto": proto,
@@ -140,37 +151,51 @@ class HostManager:
         Raises:
             None.
         """
-        result = {
-            "statistics": {
-                "total": self.__host_len__,
-                "health": 0,
-                "unhealthy": 0,
-            },
-            "health": [],
-            "unhealthy": []
-        }
-        for k in self.__host__:
-            m_uri = self.__generateHost__(self.__host_cnf__[k])
-            if m_uri:
-                m_uri += "/" + \
-                    self.__host_cnf__[k]["sniffer"].strip(
-                        '/').replace('\\', "/")
-                status, body = GET(m_uri, time_out=5)
-                if status == 200:
-                    self.__host_cnf__[k]['status'] = True
-                    result["health"].append(k)
+        while self.__monitor_state__:
+            result = {
+                "statistics": {
+                    "total": self.__host_len__,
+                    "health": 0,
+                    "unhealthy": 0,
+                },
+                "health": [],
+                "unhealthy": []
+            }
+            for k in self.__host__:
+                m_uri = self.__generateHost__(self.__host_cnf__[k])
+                if m_uri:
+                    m_uri += "/" + \
+                        self.__host_cnf__[k]["sniffer"].strip(
+                            '/').replace('\\', "/")
+                    status, body = GET(m_uri, time_out=5)
+                    if status == 200:
+                        self.__host_cnf__[k]['status'] = True
+                        logging.info("%s%s:%s%s  success."%(self.__host_cnf__[k]['proto'],self.__host_cnf__[k]['host'],self.__host_cnf__[k]['port'],self.__host_cnf__[k]['sniffer']))
+                        result["health"].append(k)
+                    else:
+                        self.__host_cnf__[k]["status"] = False
+                        logging.info("%s%s:%s%s fail."%(self.__host_cnf__[k]['proto'],self.__host_cnf__[k]['host'],self.__host_cnf__[k]['port'],self.__host_cnf__[k]['sniffer']))
+                        result["unhealthy"].append(k)
                 else:
                     self.__host_cnf__[k]["status"] = False
-                    result["unhealthy"].append(k)
-            else:
-                self.__host_cnf__[k]["status"] = False
-                result['unhealthy'].append(k)
-        for k in result["unhealthy"]:
-            self.delete(k)
-        result["statistics"]["health"] = len(result["health"])
-        result["statistics"]["unhealthy"] = len(result["unhealthy"])
-        return result
+                    logging.info("%s%s:%s%s fail."%(self.__host_cnf__[k]['proto'],self.__host_cnf__[k]['host'],self.__host_cnf__[k]['port'],self.__host_cnf__[k]['sniffer']))
+                    result['unhealthy'].append(k)
+            for k in result["unhealthy"]:
+                self.delete(k)
+            result["statistics"]["health"] = len(result["health"])
+            result["statistics"]["unhealthy"] = len(result["unhealthy"])
+            time.sleep(self.__monitor_speed__)
 
+    def __start_state_monitor__(self, speed= None):
+        self.__monitor_state__= True
+        self.__monitor_speed__= speed if speed else self.__monitor_speed__
+        monitor= Thread(target= self.health)
+        monitor.start()
+        
+    def __stop_state_monitor__(self):
+        self.__monitor_state__= False
+        self.__monitor_speed__= 10
+        
     def __generateHost__(self, uri_cnf: dict):
         proto = uri_cnf["proto"]
         host = uri_cnf["host"]
