@@ -17,7 +17,7 @@ from TDhelper.robot.struct.base import joint
 
 
 class TOE(threading.Thread):
-    def __init__(self, joints:[]= None):
+    def __init__(self, joints:list= None):
         '''
             脚趾初始化
             - params:
